@@ -4,19 +4,21 @@ import re
 from dataclasses import dataclass
 from typing import Dict, Callable, Any, Set, Union
 
-
 # Alias for docs hinting
 BeanId = str
 BeanInstance = Any
+ProfileFunction = Callable[[Set[str]], bool]
 
 
 class BeanRef(abc.ABC):
     """
     Base class for all bean definitions
     """
+
     @abc.abstractmethod
     def all_dependencies_satisfied(
-            self, ready_beans_ids: Set[BeanId], all_beans_ids: Set[BeanId]
+            self, ready_beans_ids: Set[BeanId],
+            all_beans_ids: Set[BeanId]
     ) -> bool:
         """
         Indicates all dependencies of definition satisfied.
@@ -47,8 +49,10 @@ class IdBeanRef(BeanRef):
         self.optional = optional
         self.bean_id = bean_id
 
-    def all_dependencies_satisfied(self, ready_beans_ids: Set[BeanId],
-                                   all_beans_ids: Set[BeanId]) -> bool:
+    def all_dependencies_satisfied(
+            self, ready_beans_ids: Set[BeanId],
+            all_beans_ids: Set[BeanId]
+    ) -> bool:
         if self.bean_id not in all_beans_ids:
             return self.optional
         else:
@@ -71,8 +75,10 @@ class WildcardBeanRef(BeanRef):
     def __init__(self, wildcard: str):
         self.wildcard = wildcard
 
-    def all_dependencies_satisfied(self, ready_beans_ids: Set[BeanId],
-                                   all_beans_ids: Set[BeanId]) -> bool:
+    def all_dependencies_satisfied(
+            self, ready_beans_ids: Set[BeanId],
+            all_beans_ids: Set[BeanId]
+    ) -> bool:
         required_beans = set(fnmatch.filter(all_beans_ids, self.wildcard))
         return ready_beans_ids >= required_beans
 
@@ -86,8 +92,10 @@ class RegexBeanRef(BeanRef):
     def __init__(self, regex: str):
         self.regex = regex
 
-    def all_dependencies_satisfied(self, ready_beans_ids: Set[BeanId],
-                                   all_beans_ids: Set[BeanId]) -> bool:
+    def all_dependencies_satisfied(
+            self, ready_beans_ids: Set[BeanId],
+            all_beans_ids: Set[BeanId]
+    ) -> bool:
         required_beans = {bean_id for bean_id in all_beans_ids
                           if re.match(self.regex, bean_id)}
         return ready_beans_ids >= required_beans
@@ -109,4 +117,4 @@ class BeanDef:
     bean_id: BeanId
     factory_func: Callable[..., BeanInstance]
     dependencies: Dict[BeanId, BeanRef]
-    profile_func: Callable[[Set[str]], bool]
+    profile_func: ProfileFunction
